@@ -1,9 +1,9 @@
 /*
  * (C) Copyright 1996-2016 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -19,19 +19,14 @@
 
 using namespace magics;
 
-DriverStatic::DriverStatic() 
-{
-}
+DriverStatic::DriverStatic() {}
 
-DriverStatic::~DriverStatic() 
-{
-}
+DriverStatic::~DriverStatic() {}
 
 /*!
  Class information are given to the output-stream.
-*/		
-void DriverStatic::print(ostream& out)  const
-{
-	out << "DriverStatic[";
-	out << "]";
+*/
+void DriverStatic::print(ostream& out) const {
+    out << "DriverStatic[";
+    out << "]";
 }
