@@ -1,20 +1,20 @@
 /*
  * (C) Copyright 1996-2016 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
 /*! \file Flag.cc
     \brief Implementation of the Template class Flag.
-    
+
     Magics Team - ECMWF 2005
-    
+
     Started: Wed 16-Mar-2005
-    
+
     Changes:
 */
 
@@ -23,21 +23,15 @@
 using namespace magics;
 
 
-Flag::Flag() : length_(1), convention_(SI)
-{
-}
+Flag::Flag() : length_(1), convention_(SI) {}
 
 
-Flag::~Flag() 
-{
-}
+Flag::~Flag() {}
 
 /*!
  Class information are given to the output-stream.
-*/	
-	
-void Flag::print(ostream& out)  const
-{
-	out << "Flag";
+*/
+
+void Flag::print(ostream& out) const {
+    out << "Flag";
 }
-	
