@@ -21,7 +21,7 @@
 
 
 #include "AxisItem.h"
-#include <DateTime.h>
+#include <MagDateTime.h>
 #include <cfloat>
 #include <locale>
 #include "Axis.h"
