@@ -1,9 +1,9 @@
 /*
  * (C) Copyright 1996-2016 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -22,30 +22,27 @@
 #ifndef Filter_H
 #define Filter_H
 
-#include "magics.h"
-#include "UserPoint.h"
 #include "MatrixHandler.h"
+#include "UserPoint.h"
+#include "magics.h"
 namespace magics {
 
 
-class Filter: public vector<UserPoint>
-{
-public :
-
+class Filter : public vector<UserPoint> {
+public:
     Filter(MatrixHandler& matrix, int nrows, int ncols);
     virtual ~Filter();
 
     //!  Get number of columns of the Mask
-    int DimensionX () const { return ncols_; }
+    int DimensionX() const { return ncols_; }
 
     //!  Get number of lines of the Mask
-    int DimensionY () const { return nrows_; }
+    int DimensionY() const { return nrows_; }
 
     //!  Start the processing of the filters
-    virtual bool Process () { return true; }
-
-protected :
+    virtual bool Process() { return true; }
 
+protected:
     /*!
       \brief Load the first lines in buffer.
       Return:
@@ -78,39 +75,39 @@ protected :
     */
     void FreeImageBuffers();
 
-//TEST, REMOVE LATER
-void test_build_data();
+    // TEST, REMOVE LATER
+    void test_build_data();
 
-     MatrixHandler& matrix_;
-     int               nrows_;    //!< number of Mask rows
-     int               ncols_;    //!< number of Mask columns
-     int               flr_;      //!< current row
-     double            **fbuf_;	  //!< Rotating buffer
+    MatrixHandler& matrix_;
+    int nrows_;      //!< number of Mask rows
+    int ncols_;      //!< number of Mask columns
+    int flr_;        //!< current row
+    double** fbuf_;  //!< Rotating buffer
 };
 
 
-class MinMaxFilter: public Filter {
+class MinMaxFilter : public Filter {
 public:
-//	MinMaxFilter (const BaseMatrixHandler& matrix, int nrows, int ncols);
-	MinMaxFilter (MatrixHandler& matrix, int nrows, int ncols, int flag=3);
+    //	MinMaxFilter (const BaseMatrixHandler& matrix, int nrows, int ncols);
+    MinMaxFilter(MatrixHandler& matrix, int nrows, int ncols, int flag = 3);
 
-	virtual ~MinMaxFilter();
+    virtual ~MinMaxFilter();
 
-        /*!
-          Convolutes the filter over the input matrix
-          Return:
-             true  if the operantion was successfull
-             false otherwise
-        */
-        virtual bool Process ();
+    /*!
+      Convolutes the filter over the input matrix
+      Return:
+         true  if the operantion was successfull
+         false otherwise
+    */
+    virtual bool Process();
 
-        //! Set min/max flag
-	void SetMinMaxFlag (int flag) { mflag_ = flag; }
-        //! Get min/max flag
-        int  GetMinMaxFlag () { return mflag_; }
+    //! Set min/max flag
+    void SetMinMaxFlag(int flag) { mflag_ = flag; }
+    //! Get min/max flag
+    int GetMinMaxFlag() { return mflag_; }
 
-//TEST, REMOVE LATER
-void test_build_data();
+    // TEST, REMOVE LATER
+    void test_build_data();
 
 private:
     //! Copy constructor - No copy allowed
@@ -118,10 +115,9 @@ private:
     //! Overloaded << operator to copy - No copy allowed
     MinMaxFilter& operator=(const MinMaxFilter&);
 
-// -- Friends
+    // -- Friends
     //! Overloaded << operator to call print().
-    friend ostream& operator<<(ostream& s,const MinMaxFilter& p)
-        { return s; }
+    friend ostream& operator<<(ostream& s, const MinMaxFilter& p) { return s; }
 
     /*!
       1 : compute low
@@ -131,8 +127,7 @@ private:
     int mflag_;
 };
 
-} // namespace magics
-
+}  // namespace magics
 
 
 #endif
