@@ -49,7 +49,7 @@ ObsTable* ObsTable::table_ = 0;
 
 
 ObsTable::ObsTable() {
-    string filename = path_.empty() ? getEnvVariable("MAGPLUS_HOME") + MAGPLUS_PATH_TO_SHARE_ + "obs.xml" : path_;
+    string filename = path_.empty() ? buildConfigPath("obs.xml") : path_;
     char buf[BUFSIZ];
     XML_Parser parser = XML_ParserCreate(NULL);
     int done;
