@@ -29,11 +29,12 @@ public:
         index_++;
     }
     virtual ~GeoObject() {}
+    string convert(const json_spirit::Value&);
     virtual void decode(const json_spirit::Value& value) {}
     void properties(const json_spirit::Value& value) {
         Object object = value.get_value<Object>();
         for (vector<Pair>::const_iterator entry = object.begin(); entry != object.end(); ++entry) {
-            properties_.insert(make_pair(entry->name_, entry->value_.get_value<string>()));
+            properties_.insert(make_pair(entry->name_, convert(entry->value_)));
         }
     }
     string name_;
@@ -50,9 +51,9 @@ public:
 
     map<string, string> properties_;
     GeoObject* parent_;
-    virtual void create(PointsList& out) {
+    virtual void create(PointsList& out, const string& ref) {
         for (vector<GeoObject*>::iterator object = objects_.begin(); object != objects_.end(); ++object) {
-            (*object)->create(out);
+            (*object)->create(out, getProperty("reference_longitude", ref));
         }
     }
     virtual void boundingBox(double& min, double& max) {
@@ -108,7 +109,6 @@ public:
     }
     bool shift_;
     virtual void print() {
-        // cout << name_ << "-->" << objects_.size() << endl;
         for (vector<GeoObject*>::iterator o = objects_.begin(); o != objects_.end(); ++o)
             (*o)->print();
     }
@@ -139,8 +139,8 @@ public:
         max = -min;
         GeoObject::boundingBox(min, max);
     }
-    void create(PointsList& out) {
-        GeoObject::create(out);
+    void create(PointsList& out, const string& ref) {
+        GeoObject::create(out, ref);
         out.push_back(new UserPoint(0, 0, 0, true));
     }
     void shift(PointsList& out) {
@@ -158,7 +158,7 @@ public:
             return GeoObject::shift(needs, out);
 
         boundingBox(min, max);
-        // cout << min << "--->" << max << endl;
+
         if (max <= -180)
             GeoObject::shift(needs, out, 360);
 
@@ -201,7 +201,18 @@ public:
     double lat_;
     double lon_;
 
-    void create(PointsList& out) {
+    void create(PointsList& out, const string& ref) {
+        double reference = tonumber(ref);
+        double min       = reference - 180;
+        double max       = reference + 180;
+        if (reference != -9999) {
+            while (lon_ < min)
+                lon_ += 360;
+            while (lon_ > max)
+                lon_ -= 360;
+        }
+
+
         UserPoint* point =
             new UserPoint(lon_, lat_, tonumber(getProperty("value", "0")), false, false, getProperty("name"));
 
@@ -255,7 +266,7 @@ public:
         }
     }
     vector<vector<pair<double, double> > > lines_;
-    void create(PointsList& out) {
+    void create(PointsList& out, const string& ref) {
         double value = tonumber(getProperty("value", "0"));
         string name  = getProperty("name");
         for (vector<vector<pair<double, double> > >::iterator line = lines_.begin(); line != lines_.end(); ++line) {
@@ -279,11 +290,115 @@ public:
     }
 };
 
+class MultiPolygon : public GeoObject {
+public:
+    MultiPolygon() {
+        ostringstream n;
+        n << "GeoPoint_" << index_;
+        name_ = n.str();
+    }
+    virtual ~MultiPolygon() {}
+    virtual void decode(const json_spirit::Value& value) {
+        Array multi = value.get_value<Array>();
+
+        for (unsigned int m = 0; m < multi.size(); m++) {
+            Array alines = multi[m].get_value<Array>();
+
+            for (unsigned int i = 0; i < alines.size(); i++) {
+                Array line = alines[i].get_value<Array>();
+                lines_.push_back(vector<pair<double, double> >());
+                lines_.back().reserve(line.size());
+
+                for (unsigned int pt = 0; pt < line.size(); pt++) {
+                    Array point = line[pt].get_value<Array>();
+                    lines_.back().push_back(make_pair(point[0].get_value<double>(), point[1].get_value<double>()));
+                }
+            }
+        }
+    }
+    vector<vector<pair<double, double> > > lines_;
+    void create(PointsList& out, const string& ref) {
+        double value = tonumber(getProperty("value", "0"));
+        string name  = getProperty("name");
+        for (vector<vector<pair<double, double> > >::iterator line = lines_.begin(); line != lines_.end(); ++line) {
+            for (vector<pair<double, double> >::iterator point = line->begin(); point != line->end(); ++point) {
+                UserPoint* upoint = new UserPoint(point->first, point->second, value, false, false, name);
+
+                out.push_back(upoint);
+            }
+            out.push_back(new UserPoint(0, 0, 0, true));
+        }
+    }
+    void shift(PointsList& out) {
+        // double value = tonumber(getProperty("value", "0"));
+        // string name  = getProperty("name");
+        // for (vector<vector<pair<double, double> > >::iterator line = lines_.begin(); line != lines_.end(); ++line) {
+        //     for (vector<pair<double, double> >::iterator point = line->begin(); point != line->end(); ++point) {
+        //         UserPoint* upoint = new UserPoint(point->first, point->second, value, false, false, name);
+        //         out.push_back(upoint);
+        //     }
+        //     out.push_back(new UserPoint(0, 0, 0, true));
+        // }
+    }
+};
+class MagPolygon : public GeoObject {
+public:
+    MagPolygon() {
+        ostringstream n;
+        n << "GeoPoint_" << index_;
+        name_ = n.str();
+    }
+    virtual ~MagPolygon() {}
+    virtual void decode(const json_spirit::Value& value) {
+        Array alines = value.get_value<Array>();
+        // WE take the first one for the first trial!
+        // The next one are the holes !
+
+        for (unsigned int i = 0; i < alines.size(); i++) {
+            Array line = alines[i].get_value<Array>();
+
+            lines_.push_back(vector<pair<double, double> >());
+            lines_.back().reserve(line.size());
+            for (unsigned int pt = 0; pt < line.size(); pt++) {
+                Array point = line[pt].get_value<Array>();
+                lines_.back().push_back(make_pair(point[0].get_value<double>(), point[1].get_value<double>()));
+            }
+        }
+    }
+    vector<vector<pair<double, double> > > lines_;
+    void create(PointsList& out, const string& ref) {
+        double value = tonumber(getProperty("value", "0"));
+        string name  = getProperty("name");
+        for (vector<vector<pair<double, double> > >::iterator line = lines_.begin(); line != lines_.end(); ++line) {
+            for (vector<pair<double, double> >::iterator point = line->begin(); point != line->end(); ++point) {
+                UserPoint* upoint = new UserPoint(point->first, point->second, value, false, false, name);
+
+                out.push_back(upoint);
+            }
+            out.push_back(new UserPoint(0, 0, 0, true));
+        }
+    }
+    void shift(PointsList& out) {
+        // double value = tonumber(getProperty("value", "0"));
+        // string name  = getProperty("name");
+        // for (vector<vector<pair<double, double> > >::iterator line = lines_.begin(); line != lines_.end(); ++line) {
+        //     for (vector<pair<double, double> >::iterator point = line->begin(); point != line->end(); ++point) {
+        //         UserPoint* upoint = new UserPoint(point->first, point->second, value, false, false, name);
+        //         out.push_back(upoint);
+        //     }
+        //     out.push_back(new UserPoint(0, 0, 0, true));
+        // }
+    }
+};  // namespace magics
+
 }  // namespace magics
 static SimpleObjectMaker<GeoPoint, GeoObject> Point("Point");
 static SimpleObjectMaker<GeoFeature, GeoObject> FeatureCollection("FeatureCollection");
 static SimpleObjectMaker<GeoObject> Feature("Feature");
 static SimpleObjectMaker<MultiLineString, GeoObject> MultiLineString("MultiLineString");
+static SimpleObjectMaker<MultiPolygon, GeoObject> MultiPolygon("MultiPolygon");
+static SimpleObjectMaker<MagPolygon, GeoObject> MagPolygon("Polygon");
+
 
 GeoJSon::GeoJSon() : current_(0), parent_(0), matrix_(0) {
     methods_["coordinates"] = &GeoJSon::coordinates;
@@ -295,6 +410,19 @@ GeoJSon::GeoJSon() : current_(0), parent_(0), matrix_(0) {
 
 GeoJSon::~GeoJSon() {}
 
+string GeoObject::convert(const json_spirit::Value& value) {
+    if (value.type() == str_type) {
+        return value.get_str();
+    }
+    if (value.type() == int_type) {
+        return tostring(value.get_int());
+    }
+    if (value.type() == real_type) {
+        return tostring(value.get_real());
+    }
+    return "";
+}
+
 MatrixHandler& GeoJSon::matrix() {
     if (!matrix_) {
         decode();
@@ -383,8 +511,18 @@ void GeoJSon::decode() {
             json_spirit::read_or_throw(is, value);
         }
         else {
-            ifstream is(path_.c_str());
-            json_spirit::read_or_throw(is, value);
+            try {
+                ifstream is(path_.c_str());
+                json_spirit::read_or_throw(is, value);
+            }
+            catch (json_spirit::Error_position e) {
+                MagLog::error() << "JSON error in file: " << path_ << ": " << e.reason_ << "[line: " << e.line_;
+                return;
+            }
+            catch (...) {
+                MagLog::error() << "GeoJSon decoder: can not read file " << path_ << endl;
+                return;
+            }
         }
         dig(value);
     }
@@ -393,7 +531,7 @@ void GeoJSon::decode() {
         abort();
     }
     if (parent_) {
-        parent_->create(*this);
+        parent_->create(*this, "-9999");
         parent_->shift(*this);
     }
 }
