@@ -12,18 +12,15 @@ import numpy as np
 from Magics import macro as magics
 
 ref = "xarray2"
-
 ds = xr.open_dataset('netcdf3_t_z.nc')
 
 png = magics.output(output_name_first_page_number = "off", output_name = ref)
-
+data = magics.mxarray(
+        xarray_dataset = ds,
+        xarray_variable_name = "z",
+        xarray_dimension_settings = {
+            "time": np.datetime64('2017-10-13T00:00:00.000000000'),
+            "level": 925}),
 contour = magics.mcont(contour_automatic_setting = "ecmwf")
 
-magics.plot(
-        png,
-        magics.mxarray(ds = ds,
-            var = "z",
-            time = np.datetime64('2017-10-13T00:00:00.000000000'),
-            level = 925),
-        contour,
-        magics.mcoast())
+magics.plot(png, data, contour, magics.mcoast())
